# Generated by Django 4.2.5 on 2024-03-27 12:42

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone
import uuid
from comments.validators import comment_text_hashtags_validator


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("contenttypes", "0002_remove_content_type_name"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("openbook_common", "0009_linkpreview_icon"),
        ("openbook_auth", "0022_userprofile_favorite_insights"),
        ("openbook_posts", "0022_postcomment_remove_post_id"),
    ]

    operations = [
        migrations.SeparateDatabaseAndState(
            state_operations=[
                migrations.CreateModel(
                    name="Comment",
                    fields=[
                        (
                            "id",
                            models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False),
                        ),
                        ("commentable_id", models.UUIDField()),
                        ("created", models.DateTimeField(db_index=True, editable=False)),
                        ("modified", models.DateTimeField(db_index=True, default=django.utils.timezone.now)),
                        (
                            "text",
                            models.TextField(
                                max_length=1500,
                                validators=[comment_text_hashtags_validator],
                                verbose_name="text",
                            ),
                        ),
                        ("is_edited", models.BooleanField(default=False)),
                        ("is_deleted", models.BooleanField(default=False)),
                        (
                            "commentable_type",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE, to="contenttypes.contenttype"
                            ),
                        ),
                        (
                            "commenter",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE,
                                related_name="comments",
                                to=settings.AUTH_USER_MODEL,
                            ),
                        ),
                        (
                            "language",
                            models.ForeignKey(
                                null=True,
                                on_delete=django.db.models.deletion.SET_NULL,
                                related_name="post_comments",
                                to="openbook_common.language",
                            ),
                        ),
                    ],
                    options={
                        "db_table": "openbook_posts_postcomment",
                    },
                ),
                migrations.CreateModel(
                    name="CommentUserMention",
                    fields=[
                        (
                            "id",
                            models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False),
                        ),
                        (
                            "post_comment",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE,
                                related_name="user_mentions",
                                to="comments.comment",
                            ),
                        ),
                        (
                            "user",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE,
                                related_name="comment_mentions",
                                to=settings.AUTH_USER_MODEL,
                            ),
                        ),
                    ],
                    options={
                        "db_table": "openbook_posts_postcommentusermention",
                        "unique_together": {("user", "post_comment")},
                    },
                ),
                migrations.CreateModel(
                    name="CommentLinks",
                    fields=[
                        (
                            "id",
                            models.BigAutoField(
                                auto_created=True, primary_key=True, serialize=False, verbose_name="ID"
                            ),
                        ),
                        (
                            "linkpreview",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE, to="openbook_common.linkpreview"
                            ),
                        ),
                        (
                            "postcomment",
                            models.ForeignKey(
                                db_column="postcomment_id",
                                on_delete=django.db.models.deletion.CASCADE,
                                to="comments.comment",
                            ),
                        ),
                    ],
                    options={
                        "db_table": "openbook_posts_postcomment_links",
                    },
                ),
                migrations.AddField(
                    model_name="comment",
                    name="links",
                    field=models.ManyToManyField(
                        blank=True, related_name="+", through="comments.CommentLinks", to="openbook_common.linkpreview"
                    ),
                ),
                migrations.AddField(
                    model_name="comment",
                    name="mentions",
                    field=models.ManyToManyField(
                        blank=True,
                        related_name="mentioned_in_comments",
                        through="comments.CommentUserMention",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                migrations.AddField(
                    model_name="comment",
                    name="parent_comment",
                    field=models.ForeignKey(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="replies",
                        to="comments.comment",
                    ),
                ),
                migrations.CreateModel(
                    name="CommentReaction",
                    fields=[
                        (
                            "id",
                            models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False),
                        ),
                        ("created", models.DateTimeField(editable=False)),
                        ("reaction_type", models.CharField(choices=[("HEART", "Heart")], max_length=20)),
                        (
                            "post_comment",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE,
                                related_name="reactions",
                                to="comments.comment",
                            ),
                        ),
                        (
                            "reactor",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE,
                                related_name="comment_reactions",
                                to=settings.AUTH_USER_MODEL,
                            ),
                        ),
                    ],
                    options={
                        "db_table": "openbook_posts_postcommentreaction",
                        "unique_together": {("reactor", "post_comment")},
                    },
                ),
                migrations.CreateModel(
                    name="CommentMute",
                    fields=[
                        (
                            "id",
                            models.UUIDField(default=uuid.uuid4, editable=False, primary_key=True, serialize=False),
                        ),
                        (
                            "muter",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE,
                                related_name="comment_mutes",
                                to=settings.AUTH_USER_MODEL,
                            ),
                        ),
                        (
                            "post_comment",
                            models.ForeignKey(
                                on_delete=django.db.models.deletion.CASCADE,
                                related_name="mutes",
                                to="comments.comment",
                            ),
                        ),
                    ],
                    options={
                        "db_table": "openbook_posts_postcommentmute",
                        "unique_together": {("post_comment", "muter")},
                    },
                ),
                migrations.AddIndex(
                    model_name="comment",
                    index=models.Index(
                        fields=["commentable_type", "commentable_id"], name="openbook_po_comment_62fb0e_idx"
                    ),
                ),
            ],
            # We're reusing the old schema, so don't re-create any of it
            database_operations=[],
        )
    ]
